summaryrefslogtreecommitdiff
path: root/svtools/qa
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2016-05-27 09:43:22 +0200
committerNoel Grandin <noelgrandin@gmail.com>2016-05-27 12:59:23 +0000
commit850a8d27ca696f18ce0c529346f8bb8505499545 (patch)
tree5641e81912760029683e1c544e01af25eee23523 /svtools/qa
parent6c974272423ca19c94d8d5e182fec46836309d60 (diff)
Convert GRAPHIC to scoped enum
Change-Id: I1fd09a729cbda00f99841532e0dd3fa66bce7bea Reviewed-on: https://gerrit.libreoffice.org/25534 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'svtools/qa')
-rw-r--r--svtools/qa/unit/GraphicObjectTest.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/svtools/qa/unit/GraphicObjectTest.cxx b/svtools/qa/unit/GraphicObjectTest.cxx
index d1ee3c2abe43..22664425677f 100644
--- a/svtools/qa/unit/GraphicObjectTest.cxx
+++ b/svtools/qa/unit/GraphicObjectTest.cxx
@@ -233,11 +233,11 @@ void GraphicObjectTest::testSizeBasedAutoSwap()
void GraphicObjectTest::testTdf88836()
{
// Construction with empty bitmap -> type should be GRAPHIC_NONE
Graphic aGraphic = Bitmap();
- CPPUNIT_ASSERT_EQUAL(GRAPHIC_NONE, aGraphic.GetType());
+ CPPUNIT_ASSERT_EQUAL(int(GraphicType::NONE), int(aGraphic.GetType()));
aGraphic = Graphic(BitmapEx());
- CPPUNIT_ASSERT_EQUAL(GRAPHIC_NONE, aGraphic.GetType());
+ CPPUNIT_ASSERT_EQUAL(int(GraphicType::NONE), int(aGraphic.GetType()));
}
void GraphicObjectTest::testTdf88935()
@@ -233,11 +233,11 @@ void GraphicObjectTest::testSizeBasedAutoSwap()
void GraphicObjectTest::testTdf88836()
{
- // Construction with empty bitmap -> type should be GRAPHIC_NONE
+ // Construction with empty bitmap -> type should be GraphicType::NONE
Graphic aGraphic = Bitmap();